@@ -150,12 +150,15 @@ def process_date_range(payload, date_range):
 
 class CarnotPy:
 
-    def __init__(self, url, username, password):
+    def __init__(self, url, username, password, preset_token=None):
         self.url = url
         self.username = username
         self.password = password
+        self.preset_token = preset_token
 
     def get_token(self):
+        if self.preset_token is not None:
+            return self.preset_token
         result = requests.post(self.url + "/login/", json={"user_name": self.username, "password": self.password})
         assert result.status_code == 200
         try:
@@ -165,6 +168,11 @@ class CarnotPy:
             raise ValueError("Invalid username or password")
 
     def discover(self):
+        """
+        Get the point list of the facility
+        :return: return a point list
+        """
+        # return a point list
         token = self.get_token()
         result = requests.post(self.url + "/point-discovery/",
                                headers={"Authorization": "Bearer " + token}
@@ -172,6 +180,64 @@ class CarnotPy:
         assert result.status_code == 200
         return result.json()["result"]
 
+    def get_notifications(self, facility_name, date_range=None, ignore_acknowledged=True):
+        token = self.get_token()
+        payload={
+            "facility_name": facility_name,
+            "date_range": date_range,
+            "ignore_acknowledged": ignore_acknowledged
+        }
+        result = requests.post(
+            self.url + "/notification/",
+            json=payload,
+            headers={"Authorization": "Bearer " + token, 'Content-Type': 'application/json'}
+        )
+        assert result.status_code == 200
+        return result.json()["result"]
+
+    def get_config(self, facility_name):
+        token = self.get_token()
+        payload={
+            "facility_name": facility_name,
+        }
+        result = requests.post(
+            self.url + "/config/",
+            json=payload,
+            headers={"Authorization": "Bearer " + token, 'Content-Type': 'application/json'}
+        )
+        assert result.status_code == 200
+        return result.json()["result"]
+
+    def set_config(self, facility_name, config_name, config, config_id=None):
+        token = self.get_token()
+        result = requests.put(
+            self.url + "/config/",
+            json={
+                "facility_name": facility_name,
+                "config_name": config_name,
+                "config": config,
+                "config_id": config_id
+            },
+            headers={"Authorization": "Bearer " + token, 'Content-Type': 'application/json'}
+        )
+        assert result.status_code == 200
+        return result.json()
+
+    def get_maintenance_records(self, facility_name, date_range=None, equipment_name=None):
+        token = self.get_token()
+        payload={
+            "facility_name": facility_name,
+            "date_range": date_range,
+            "equipment_name": equipment_name
+        }
+        result = requests.post(
+            self.url + "/maintenancerecord/",
+            json=payload,
+            headers={"Authorization": "Bearer " + token, 'Content-Type': 'application/json'}
+        )
+        assert result.status_code == 200
+        return result.json()["result"]
+
     def read_history(self, sensor_ids, start_time, end_time):
         token = self.get_token()
         result = requests.post(
@@ -273,3 +339,17 @@ class CarnotPy:
         assert result.status_code == 200
         return result.json()
 
+    def add_job(self, facility_name, job_type, meta):
+        token = self.get_token()
+        result = requests.put(
+            self.url + "/job/",
+            json={
+                "facility_name": facility_name,
+                "job_type": job_type,
+                "job_status": "pending",
+                "meta": meta,
+            },
+            headers={"Authorization": "Bearer " + token, 'Content-Type': 'application/json'}
+        )
+        assert result.status_code == 200
+        return result.json()
